from tinydb import TinyDB, Query
from tinydb.operations import set
import datetime
import os

path = os.path.expanduser('~/streak')
if not os.path.exists(path):
    os.mkdir(path)
    
db = TinyDB(f'{path}/db.json')

Entry = Query()

def initialize_db():
    year = datetime.datetime.now().year
    c_year, exists = query_year(year)
    if not exists:
        insert_year(year)

def get_all():
    return db.all()

def query_year(year):
    response = db.search(Entry.year == year)

    return response, len(response) > 0


def insert_year(year):
    db.insert({
        'year': year,
        '1': {},
        '2': {},
        '3': {},
        '4': {},
        '5': {},
        '6': {},
        '7': {},
        '8': {},
        '9': {},
        '10': {},
        '11': {},
        '12': {}
    })

def get_year(year):
    response = db.search(Entry.year == year)
    year = response[0] if len(response) > 0 else {}
    return year


def update_month(year, month, data):
    db.update(set(f'{month}', data), Entry.year == year)




from setuptools import setup, find_packages

setup(
    name='streak_cal',
    version='0.1',
    author="Kacha Mukabe",
    description="A cli calendar for keeping track of streaks",
    url="https://github.com/kachaMukabe/streak",
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
        'Click',
        'tinydb'
    ],
    entry_points='''
        [console_scripts]
        streak_cal=streak.streak:cli
    ''',
)


import calendar
import datetime
import click
from colorama import init
from termcolor import colored

from streak.db import get_all, get_year, initialize_db, update_month


init()

# db.insert({str(datetime.datetime.now().year): {str(datetime.datetime.now().month): [True, False, True]}})


@click.group(invoke_without_command=True)
@click.option('-c', '--check', is_flag=True)
def cli(check):
    qal = calendar.Calendar(firstweekday=6)
    calendar.setfirstweekday(calendar.SUNDAY)
    initialize_db()
    y, m, today =  datetime.datetime.now().year, datetime.datetime.now().month, datetime.datetime.now().day
    year = get_year(y)
    click.echo(calendar.weekheader(2))
    for day in qal.monthdayscalendar(y, m):
        def format_day(d, year):
            d = str(d)
            done = False
            try:
                done = year[str(m)][d]
            except KeyError:
                if not d == "0":
                    year[str(m)][d] = False
            if str(today) == d and check:
                year[str(m)][d] = True
                done = True
            if d == "0":
                d = '  '
            elif len(d) == 1:
                d = colored(f' {d}', 'red', attrs=['blink', 'bold']) if done else f' {d}'
            return colored(d, 'red') if done else d
        click.echo(" ".join([format_day(x, year) for x in day]))
    update_month(y,m, year[str(m)])

if __name__ == "__main__":
    cli()